package com.docus.server.message.rpc.impl;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.docus.core.util.DateUtil;
import com.docus.server.message.config.ShunDePeopleInterfaceConfig;
import com.docus.server.message.rpc.ShunDePeopleRpc;
import com.docus.server.message.rpc.request.HisZyCyYzRequest;
import com.docus.server.message.rpc.response.HisZyCyYzResponse;
import com.docus.server.message.util.HttpUrlUtil;
import com.docus.server.message.util.IdUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Map;

/**
 * 顺德人医远程调用实现
 * @author wyb
 */
@Slf4j
@Service
public class ShunDePeopleRpcImpl implements ShunDePeopleRpc {

    @Override
    public HisZyCyYzResponse hisZyCyYz(HisZyCyYzRequest request) {
        ShunDePeopleInterfaceConfig.InterfaceConfig interfaceConfig = ShunDePeopleInterfaceConfig.getTaskConfig("HIS_ZY_CYYZ");
        if(interfaceConfig==null){
            log.warn("查询住院出院医嘱接口未配置！");
            return null;
        }
        // 组织url
        String standardUuId = IdUtil.standardUUID();
        String timeMini = DateUtil.formatDateTimeMini(LocalDateTime.now());
        Map<String, String> otherParam = interfaceConfig.getOtherParam();
        otherParam.put("uuid",standardUuId);
        otherParam.put("creationTime",timeMini);
        String url = HttpUrlUtil.addUrlParam(interfaceConfig.getUrl(), otherParam);
        try {
            log.info("[{}]:查询住院出院医嘱接口地址:{}",standardUuId,url);
            String resp = HttpUtil.post(url, JSON.toJSONString(request));
            log.info("[{}]:查询住院出院医嘱接口返回值：{}",standardUuId,resp);
            return JSON.parseObject(resp, new TypeReference<HisZyCyYzResponse>() {
            });
        }catch (Exception ex){
            log.error("["+standardUuId+"]:"+"查询住院出院医嘱接口出错啦！===》"+ex.getMessage(),ex);
            return null;
        }
    }



    public static void main(String[] args) {

    }
}
